@@ -151,6 +151,14 @@ class Topic(models.Model):
         except IndexError:
             return None
 
+    def get_image(self):
+        """
+        Gets first image from post set.
+        """
+        posts_with_images =  self.post_set.filter(image__gt='')
+        if posts_with_images:
+            return posts_with_images[0].image
+
 
 class Post(BaseUserContentModel):
     topic = models.ForeignKey(Topic)
